==> haskell-bz2-1.0.1.1-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bz2
version:              1.0.1.1
visibility:           public
id:                   bz2-1.0.1.1-Iw93mJpbFW2AxGKlAaYKfl
key:                  bz2-1.0.1.1-Iw93mJpbFW2AxGKlAaYKfl
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  a68f7e01d67decf3c8c49ed1f44c6705
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Common Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Unpack Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.1-Iw93mJpbFW2AxGKlAaYKfl
extra-libraries:      bz2
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bz2-1.0.1.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bz2
version:              1.0.1.1
visibility:           public
id:                   bz2-1.0.1.1-7RJUw6QA7xoL8bTJBaH38r
key:                  bz2-1.0.1.1-7RJUw6QA7xoL8bTJBaH38r
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  6588e9b1362a226e4b2ec942418a0133
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Common Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Unpack Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.1-7RJUw6QA7xoL8bTJBaH38r
extra-libraries:      bz2
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
